@@ -8,10 +8,10 @@ JackknifeVariance=function(n,r,pi,strata=FALSE,cluster=FALSE,clu=NULL){
   
   if(!is.vector(pi)){stop("pi must be a vector.")}
   if(any(is.na(pi))){stop("There are missing values in pi.")}
-  if(any((pi<=0)||(pi>1))){stop("There are invalid values in pi.")}         
+  if(any((pi<=0)|(pi>1))){stop("There are invalid values in pi.")}         
   if(length(pi)!=length(r)){stop("The lengths of pi and r are different.")}                 
   
-  if(((strata==FALSE)&&(cluster==FALSE))||((strata==TRUE)&&(cluster==FALSE))){
+  if(((strata==FALSE)&(cluster==FALSE))|((strata==TRUE)&(cluster==FALSE))){
     Je=vector()
     for(i in 1:n){
       wi=1/(pi[-i]*((n-1)/n))
@@ -20,7 +20,7 @@ JackknifeVariance=function(n,r,pi,strata=FALSE,cluster=FALSE,clu=NULL){
     Jve=(1-mean(pi))*((n-1)/n)*sum((Je-mean(Je))^2)
   }
   
-  if(((strata==FALSE)&&(cluster==TRUE))||((strata==TRUE)&&(cluster==TRUE))){
+  if(((strata==FALSE)&(cluster==TRUE))|((strata==TRUE)&(cluster==TRUE))){
     Je=vector()
     for(i in levels(clu)){
      wi=1/(pi[clu!=i]*((n-1)/n))
